use crate::models::{CTAResponse, Ctatt};
use serde::{Deserialize, Serialize};

#[derive(Serialize, Debug)]
pub struct FollowRequest {
    #[serde(rename = "runnumber")]
    pub run_number: u32,
}

#[derive(Deserialize, Debug, Default)]
pub struct Position {
    pub lat: String,
    pub lon: String,
    pub heading: String,
}

#[derive(Deserialize, Debug)]
pub struct ScheduledStop {
    #[serde(rename = "staId")]
    pub sta_id: String,
    #[serde(rename = "stpId")]
    pub stp_id: String,
    #[serde(rename = "staNm")]
    pub sta_nm: String,
    #[serde(rename = "stpDe")]
    pub stp_de: String,
    pub rn: String,
    pub rt: String,
    #[serde(rename = "destSt")]
    pub dest_st: String,
    #[serde(rename = "destNm")]
    pub tr_dr: String,
    pub prdt: String,
    #[serde(rename = "arrT")]
    pub arr_t: String,
    #[serde(rename = "isApp")]
    pub is_app: String,
    #[serde(rename = "isSch")]
    pub is_sch: String,
    #[serde(rename = "isDly")]
    pub is_dly: String,
    #[serde(rename = "isFlt")]
    pub is_flt: String,
    pub flags: Option<String>,
}

#[derive(Deserialize, Debug)]
pub struct FollowResp {
    #[serde(flatten)]
    pub header: Ctatt,
    #[serde(default)]
    pub position: Position,
    #[serde(default)]
    pub eta: Vec<ScheduledStop>,
}

impl CTAResponse for FollowResp {
    fn get_header(&self) -> Ctatt {
        self.header.clone()
    }
}
